local addon = _G.LFGTimer;

local config = addon:NewModule("Config");

addon.Config = config;

local L = LibStub("AceLocale-3.0"):GetLocale("LFGTimer");
local db;

function config:OnInitialize()
	db = addon.Vars.profile;
	
	addon.Vars.RegisterCallback(self, "OnProfileChanged", "UpdateDB");
	addon.Vars.RegisterCallback(self, "OnProfileCopied", "UpdateDB");
	addon.Vars.RegisterCallback(self, "OnProfileReset", "UpdateDB");
	
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("LFGTimer", self.Options);
	
	self.Options.args.Profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(addon.Vars);
end

function config:UpdateDB(event, database)
	db = database.profile;
end

function config:Show()
	LibStub("AceConfigDialog-3.0"):Open("LFGTimer");
end

config.Options = {
	type = "group",
	order = 1,
	name = "LFG Timer",
	childGroups = 'tree',
	get = function(info)
		return db[ info[#info] ];
	end,
	set = function(info, value)
		db[ info[#info] ] = value;
		addon:UpdateFrameArt();
		addon:UpdateFrameShown();
	end,
	args = {
		FrameDisplay = {
			type = 'group',
			order = 1,
			name = L["Frame options"],
			childGroups = 'tab',
			disabled = function()
				return not db.Frame.Show;
			end,
			get = function(info)
				return db.Frame[ info[#info] ];
			end,
			set = function(info, value)
				db.Frame[ info[#info] ] = value;
				addon:UpdateFrameArt();
				addon:UpdateFrameShown();
			end,
			args = {
				General = {
					type = 'group',
					order = 1,
					name = L["General"],
					desc = L["General frame options."],
					args = {
						Show = {
							type = 'toggle',
							order = 1,
							name = L["Show frame"],
							desc = L["Show a queue status frame."],
							disabled = false,
						},
						Locked = {
							type = 'toggle',
							order = 2,
							name = L["Lock the frame"],
							desc = L["Lock the frame in place, preventing it from being moved."],
						},
						Type = {
							type = 'select',
							order = 3,
							name = L["Frame type"],
							desc = L["Type of queue status frame to show.\n\n|cffffd200Queue status clone|r: Clone of the Blizzard Queue Status frame. This is a graphical frame.\n\n|cffffd200Text tooltip|r: Customizable tooltip that can show detailed information about queues. This IS NOT a graphical frame."],
							values = {
								clone = L["Queue status clone"],
								custom = L["Text tooltip"],
							},
						},
					},
				},
				ShowWhen = {
					type = 'group',
					order = 2,
					name = L["Show when"],
					desc = L["Control when the queue status frame is shown."],
					args = {
						States = {
							type = 'group',
							order = 1,
							guiInline = true,
							name = L["By queue status"],
							get = function(info)
								return db.Frame.Queue.States[ info[#info] ];
							end,
							set = function(info, value)
								db.Frame.Queue.States[ info[#info] ] = value;
								addon:UpdateFrameArt();
								addon:UpdateFrameShown();
							end,
							args = {
								notQueued = {
									type = 'toggle',
									order = 1,
									name = L["Not queued"],
									desc = L["Show the queue status frame when not queued for an activity."],
								},
								proposal = {
									type = 'toggle',
									order = 2,
									name = L["Queue available"],
									desc = L["Show the queue status frame when an active queue prompts the user to accept."],
								},
								inParty = {
									type = 'toggle',
									order = 3,
									name = L["In a group"],
									desc = L["Show the queue status frame when the user is in an instance group or battleground raid."],
								},
								queuedNoData = {
									type = 'toggle',
									order = 3,
									name = L["Acquiring queue data"],
									desc = L["Show the queue status frame when queued but before relavent queue data is available."],
								},
								queued = {
									type = 'toggle',
									order = 3,
									name = L["In a queue"],
									desc = L["Show the queue status frame while queued."],
								},
							},
						},
						Types = {
							type = 'group',
							order = 2,
							guiInline = true,
							name = L["By queue type"],
							get = function(info)
								return db.Frame.Queue.Types[ info[#info] ];
							end,
							set = function(info, value)
								db.Frame.Queue.Types[ info[#info] ] = value;
								addon:UpdateFrameArt();
								addon:UpdateFrameShown();
							end,
							args = {
								LookingForDungeon = {
									type = 'toggle',
									order = 1,
									name = L["Looking for Dungeon"],
									desc = L["Show queue information for Looking for Dungeon queues. This includes random, specific and/or heroic dungeon queues but does not include Looking for Raid or Scenario queues."],
								},
								RaidFinder = {
									type = 'toggle',
									order = 2,
									name = L["Raid Finder"],
									desc = L["Show queue information for Raid Finder listings. This does not include Looking for Raid queues."]
								},
								Scenarios = {
									type = 'toggle',
									order = 3,
									name = L["Scenarios"],
									desc = L["Show queue information for a Scenario queues. This includes random or specific scenario queues but does not include Looking for Raid or Looking for Dungeon queues."],
								},
								LookingForRaid = {
									type = 'toggle',
									order = 4,
									name = L["Looking for Raid"],
									desc = L["Show queue information for Looking for Raid queues. This does not include Raid Finder listings."]
								},
								PvP = {
									type = 'toggle',
									order = 5,
									name = L["Battleground & Arena"],
									desc = L["Show queue information for Battleground and Arena queues. This includes Rated Battleground and Arena Skirmish queues. but does not include World PvP queues."]
								},
								WorldPvP = {
									type = 'toggle',
									order = 6,
									name = L["World PvP"],
									desc = L["Show queue information for World PvP queues. This includes Wintergrasp and Tol Barad."]
								},
							},
						},
					},
				},
				Data = {
					type = 'group',
					order = 3,
					name = L["Tooltip data"],
					desc = L["Control what information the Text Tooltip frame displays."],
					disabled = function()
						return not db.Frame.Show or db.Frame.Type ~= 'custom';
					end,
					childGroups = 'select',
					args = {
						LookingForDungeon = {
							type = 'group',
							order = 1,
							name = L["Looking for Dungeon"],
							args = {
								QueueTimes = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Queue times"],
									get = function(info)
										return db.Frame.Queue.Data.LookingForDungeon.QueueTimes[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.LookingForDungeon.QueueTimes[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tank queue times"],
											desc = L["Show queue time information for the Tank role."],
										},
										Healer = {
											type = 'toggle',
											order = 1,
											name = L["Healer queue times"],
											desc = L["Show queue time information for the Healer role."],
										},
										DPS = {
											type = 'toggle',
											order = 1,
											name = L["DPS queue times"],
											desc = L["Show queue time information for the DPS role."],
										},
										Self = {
											type = 'toggle',
											order = 1,
											name = L["Your queue times"],
											desc = L["Show queue time information for your group."],
										},
									},
								},
								Party = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Party members found"],
									get = function(info)
										return db.Frame.Queue.Data.LookingForDungeon.Party[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.LookingForDungeon.Party[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tanks found"],
											desc = L["Show information on the number of Tanks found versus the total needed."],
										},
										Healer = {
											type = 'toggle',
											order = 2,
											name = L["Healers found"],
											desc = L["Show information on the number of Healers found versus the total needed."],
										},
										DPS = {
											type = 'toggle',
											order = 3,
											name = L["DPS found"],
											desc = L["Show information on the number of DPS found versus the total needed."],
										},
										Total = {
											type = 'toggle',
											order = 4,
											name = L["Party members"],
											desc = L["Show information on the number of party members found versus the total needed."],
										},
									},
								},
							},
						},
						RaidFinder = {
							type = 'group',
							order = 2,
							name = L["Raid Finder"],
							args = {
								QueueTimes = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Queue times"],
									get = function(info)
										return db.Frame.Queue.Data.RaidFinder.QueueTimes[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.RaidFinder.QueueTimes[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tank queue times"],
											desc = L["Show queue time information for the Tank role."],
										},
										Healer = {
											type = 'toggle',
											order = 1,
											name = L["Healer queue times"],
											desc = L["Show queue time information for the Healer role."],
										},
										DPS = {
											type = 'toggle',
											order = 1,
											name = L["DPS queue times"],
											desc = L["Show queue time information for the DPS role."],
										},
										Self = {
											type = 'toggle',
											order = 1,
											name = L["Your queue times"],
											desc = L["Show queue time information for your group."],
										},
									},
								},
								Party = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Party members found"],
									get = function(info)
										return db.Frame.Queue.Data.RaidFinder.Party[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.RaidFinder.Party[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tanks found"],
											desc = L["Show information on the number of Tanks found versus the total needed."],
										},
										Healer = {
											type = 'toggle',
											order = 2,
											name = L["Healers found"],
											desc = L["Show information on the number of Healers found versus the total needed."],
										},
										DPS = {
											type = 'toggle',
											order = 3,
											name = L["DPS found"],
											desc = L["Show information on the number of DPS found versus the total needed."],
										},
										Total = {
											type = 'toggle',
											order = 4,
											name = L["Party members"],
											desc = L["Show information on the number of party members found versus the total needed."],
										},
									},
								},
							},
						},
						Scenarios = {
							type = 'group',
							order = 2,
							name = L["Scenarios"],
							args = {
								QueueTimes = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Queue times"],
									get = function(info)
										return db.Frame.Queue.Data.Scenarios.QueueTimes[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.Scenarios.QueueTimes[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tank queue times"],
											desc = L["Show queue time information for the Tank role."],
										},
										Healer = {
											type = 'toggle',
											order = 1,
											name = L["Healer queue times"],
											desc = L["Show queue time information for the Healer role."],
										},
										DPS = {
											type = 'toggle',
											order = 1,
											name = L["DPS queue times"],
											desc = L["Show queue time information for the DPS role."],
										},
										Self = {
											type = 'toggle',
											order = 1,
											name = L["Your queue times"],
											desc = L["Show queue time information for your group."],
										},
									},
								},
								Party = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Party members found"],
									get = function(info)
										return db.Frame.Queue.Data.Scenarios.Party[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.Scenarios.Party[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tanks found"],
											desc = L["Show information on the number of Tanks found versus the total needed."],
										},
										Healer = {
											type = 'toggle',
											order = 2,
											name = L["Healers found"],
											desc = L["Show information on the number of Healers found versus the total needed."],
										},
										DPS = {
											type = 'toggle',
											order = 3,
											name = L["DPS found"],
											desc = L["Show information on the number of DPS found versus the total needed."],
										},
										Total = {
											type = 'toggle',
											order = 4,
											name = L["Party members"],
											desc = L["Show information on the number of party members found versus the total needed."],
										},
									},
								},
							},
						},
						LookingForRaid = {
							type = 'group',
							order = 4,
							name = L["Looking for Raid"],
							args = {
								QueueTimes = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Queue times"],
									get = function(info)
										return db.Frame.Queue.Data.LookingForRaid.QueueTimes[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.LookingForRaid.QueueTimes[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tank queue times"],
											desc = L["Show queue time information for the Tank role."],
										},
										Healer = {
											type = 'toggle',
											order = 1,
											name = L["Healer queue times"],
											desc = L["Show queue time information for the Healer role."],
										},
										DPS = {
											type = 'toggle',
											order = 1,
											name = L["DPS queue times"],
											desc = L["Show queue time information for the DPS role."],
										},
										Self = {
											type = 'toggle',
											order = 1,
											name = L["Your queue times"],
											desc = L["Show queue time information for your group."],
										},
									},
								},
								Party = {
									type = 'group',
									order = 1,
									guiInline = true,
									name = L["Party members found"],
									get = function(info)
										return db.Frame.Queue.Data.LookingForRaid.Party[ info[#info] ];
									end,
									set = function(info, value)
										db.Frame.Queue.Data.LookingForRaid.Party[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
									end,
									args = {
										Tank = {
											type = 'toggle',
											order = 1,
											name = L["Tanks found"],
											desc = L["Show information on the number of Tanks found versus the total needed."],
										},
										Healer = {
											type = 'toggle',
											order = 2,
											name = L["Healers found"],
											desc = L["Show information on the number of Healers found versus the total needed."],
										},
										DPS = {
											type = 'toggle',
											order = 3,
											name = L["DPS found"],
											desc = L["Show information on the number of DPS found versus the total needed."],
										},
										Total = {
											type = 'toggle',
											order = 4,
											name = L["Party members"],
											desc = L["Show information on the number of party members found versus the total needed."],
										},
									},
								},
							},
						},
						PvP = {
							type = 'group',
							order = 5,
							name = L["Player vs Player"],
							get = function(info)
								return db.Frame.Queue.Data.PvP[ info[#info] ];
							end,
							set = function(info, value)
								db.Frame.Queue.Data.PvP[ info[#info] ] = value;
										addon:UpdateFrameArt();
										addon:UpdateFrameShown();
							end,
							args = {
								LevelRange = {
									type = 'toggle',
									order = 1,
									name = L["Level range"],
									desc = L["Show the level range for the selected PvP queue.\n\n|cffffd200Note|r: Some battleground queues always report the the minimum required level as zero (0)."],
								},
								TeamSize = {
									type = 'toggle',
									order = 2,
									name = L["Team size"],
									desc = L["Show the team size for the selected PvP queue.\n\n|cffffd200Note|r: Some battleground queues always report the team size as zero (0)."],
								},
								WaitTime = {
									type = 'toggle',
									order = 3,
									name = L["Wait time"],
									desc = L["Show the estimated wait time."],
								},
							},
						},
						WorldPvP = {
							type = 'group',
							order = 5,
							name = L["World PvP"],
							get = function(info)
								return db.Frame.Queue.Data.WorldPvP[ info[#info] ];
							end,
							set = function(info, value)
								db.Frame.Queue.Data.WorldPvP[ info[#info] ] = value;
								addon:UpdateFrameArt();
								addon:UpdateFrameShown();
							end,
							args = {
								TimeLeft = {
									type = 'toggle',
									order = 1,
									name = L["Time left"],
									desc = L["Show the time remaining for the selected World PvP battle.\n\n|cffffd200Note|r: Some World PvP queues may not support this value."],
								},
							},
						},
					},
				},
				Art = {
					type = 'group',
					order = 4,
					name = L["Artwork and text"],
					desc = L["Control how the Text Tooltip frame looks."],
					childGroups = 'tab',
					disabled = function()
						return not db.Frame.Show or db.Frame.Type ~= 'custom';
					end,
					args = {
						Backdrop = {
							type = 'group',
							order = 2,
							name = L["Backdrop"],
							desc = L["Background and border options"],
							get = function(info)
								if info.type == 'color' then
									local t = db.Frame.Backdrop[ info[#info] ];
									return t.r, t.g, t.b, t.a;
								else
									return db.Frame.Backdrop[ info[#info] ];
								end
							end,
							set = function(info, ...)
								if info.type == 'color' then
									local t = db.Frame.Backdrop[ info[#info] ];
									t.r, t.g, t.b, t.a = ...;
								else
									db.Frame.Backdrop[ info[#info] ] = ...;
								end
								addon:UpdateFrameArt();
							end,
							args = {
								Background = {
									type = 'select',
									order = 1,
									name = L["Background texture"],
									desc = L["Texture used as the tooltip's background."],
									dialogControl = 'LSM30_Background',
									values = AceGUIWidgetLSMlists.background,
									width = 'full',
								},
								BackgroundColor = {
									type = 'color',
									order = 2,
									name = L["Background texture color"],
									desc = L["Color used to tint the tooltip's background texture.\n|cffffd200Note|r: Darker textures are less effected by this option."],
									width = 'full',
								},
								Tile = {
									type = 'toggle',
									order = 3,
									name = L["Tile the background texture"],
									desc = L["Repeat the background texture horizontally and vertically."],
									width = 'full',
								},
								TileSize = {
									type = 'range',
									order = 4,
									name = L["Background tile size"],
									desc = L["Size of the blocks used when tiling the background texture."],
									width = 'full',
									min = 2,
									max = 64,
									step = 1,
									bigStep = 2,
									disabled = function(info)
										return not db.Frame.Backdrop.Tile;
									end,
								},
								Inset = {
									type = 'range',
									order = 5,
									name = L["Background inset"],
									desc = L["Distance between the border and the background texture."],
									width = 'full',
									min = 0,
									max = 32,
									step = 1,
									bigStep = 2,
								},
								Border = {
									type = 'select',
									order = 7,
									name = L["Border texture"],
									desc = L["Texture used as the tooltip's border."],
									dialogControl = 'LSM30_Border',
									values = AceGUIWidgetLSMlists.border,
									width = 'full',
								},
								BorderColor = {
									type = 'color',
									order = 8,
									name = L["Border texture color"],
									desc = L["Color used to tint the tooltip's border texture.\n|cffffd200Note|r: Darker textures are less effected by this option."],
									width = 'full',
								},
								EdgeSize = {
									type = 'range',
									order = 9,
									name = L["Border size"],
									desc = L["Thickness of the border texture."],
									width = 'full',
									min = 2,
									max = 32,
									step = 1,
									bigStep = 2,
								},
							},
						},
						Text = {
							type = 'group',
							order = 3,
							name = L["Text"],
							desc = L["Text appearance options"],
							get = function(info)
								if info.type == 'color' then
									local t = db.Frame.Text[ info[#info] ];
									return t.r, t.g, t.b, t.a;
								else
									return db.Frame.Text[ info[#info] ];
								end
							end,
							set = function(info, ...)
								if info.type == 'color' then
									local t = db.Frame.Text[ info[#info] ];
									t.r, t.g, t.b, t.a = ...;
								else
									db.Frame.Text[ info[#info] ] = ...;
								end
							end,
							args = {
								Font = {
									type = 'select',
									order = 1,
									name = L["Font"],
									desc = L["Font used for the tooltip text."],
									dialogControl = 'LSM30_Font',
									values = AceGUIWidgetLSMlists.font,
									width = 'full',
								},
								Size = {
									type = 'range',
									order = 2,
									name = L["Text size"],
									desc = L["Font size used for the tooltip text."],
									width = 'full',
									min = 4,
									max = 20,
									step = 1,
								},
								Outline = {
									type = 'select',
									order = 3,
									name = L["Text outline"],
									desc = L["Add an outline to the tooltip text."],
									width = 'full',
									values = {
										[" "] = L["No outline"],
										["OUTLINE"] = L["Thin outline"],
										["THICKOUTLINE"] = L["Thick outline"],
									},
								},
								Color = {
									type = 'color',
									order = 4,
									name = L["Text color"],
									desc = L["Color used for the tooltip text."],
									width = 'full',
								},
							},
						},
					},
				},
			},
		},
	
	--[===[
		General = {
			type = 'group',
			order = 1,
			name = L["Frame display"],
			hidden = function(info)
				return not db.ShowFrame;
			end,
			childGroups = 'tab',
			args = {
				ShowFrame = {
					type = 'toggle',
					order = 1,
					name = L["Show frame"],
					desc = L["Show a queue status window"],
					hidden = false,
				},
				FrameType = {
					type = 'select',
					order = 2,
					name = L["Frame type"],
					desc = L["Type of search status frame to show.\n\n|cffffd200Search status clone|r: Clone of the Blizzard Queue Status frame.\n\n|cffffd200Customizable tooltip|r: Customizable tooltip that can show detailed information about queues."],
					values = {
						clone = L["Search status clone"],
						custom = L["Customizable tooltip"],
					},
				},
				FrameLocked = {
					type = 'toggle',
					order = 3,
					name = L["Lock frame"],
					desc = L["Lock the frame in place, preventing it from being moved."],
				},
				ShowWhen = {
					type = 'group',
					order = 4,
					name = L["Show when..."],
					guiInline = true,
					get = function(info)
						return db.Frame.ShowWhen[ info[#info] ];
					end,
					set = function(info, value)
						db.Frame.ShowWhen[ info[#info] ] = value;
					end,
					args = {
						Not = {
							type = "toggle",
							order = 1,
							name = L["Not queued"],
							desc = L["Show the frame when you are not in an LFG queue."],
							width = 'full',
						},
						Acquire = {
							type = "toggle",
							order = 2,
							name = L["Acquiring data"],
							desc = L["Show the frame while acquring LFG queue data."],
							width = 'full',
						},
						Wait = {
							type = "toggle",
							order = 3,
							name = L["Waiting for a group"],
							desc = L["Show the frame while waiting in the queue."],
							width = 'full',
						},
						Party = {
							type = "toggle",
							order = 4,
							name = L["In a party"],
							desc = L["Show the frame while in an LFG party."],
							width = 'full',
						},
						Found = {
							type = "toggle",
							order = 5,
							name = L["Group found"],
							desc = L["Show the frame when a group is found."],
							width = 'full',
						},
					},
				},
				ShowFor = {
					type = 'group',
					order = 4,
					name = L["Show for..."],
					guiInline = true,
					get = function(info)
						return db.Frame.ShowFor[ info[#info] ];
					end,
					set = function(info, value)
						db.Frame.ShowFor[ info[#info] ] = value;
					end,
					args = {
						Dungeons = {
							type = "toggle",
							order = 1,
							name = L["Dungeon queues"],
							desc = L["Show information for Looking for Dungeon queues. |cffffd200Note|r: This includes random, specific and heroic dungeon queues."],
							width = 'full',
						},
						RaidFinder = {
							type = "toggle",
							order = 2,
							name = L["Raid Finder listing"],
							desc = L["Show information for Raid Finder listings. |cffffd200Note|r: This DOES NOT include Looking for Raid queues."],
							width = 'full',
						},
						Scenarios = {
							type = "toggle",
							order = 3,
							name = L["Scenario queues"],
							desc = L["Show information for Looking for Scenario queues."],
							width = 'full',
						},
						LookingForRaid = {
							type = "toggle",
							order = 4,
							name = L["Looking for Raid queues"],
							desc = L["Show information for Looking for Raid queues. |cffffd200Note|r: This DOES NOT include Raid Finder listings."],
							width = 'full',
						},
						Arena = {
							type = "toggle",
							order = 4,
							name = L["Arena queues"],
							desc = L["Show information for Arena queues. |cffffd200Note|r: This DOES NOT include Rated Battleground queues."],
							width = 'full',
						},
						Battleground = {
							type = "toggle",
							order = 5,
							name = L["Battleground queues"],
							desc = L["Show information for Battleground queues. |cffffd200Note|r: This includes Rated Battleground queues."],
							width = 'full',
						},
						Battleground = {
							type = "toggle",
							order = 6,
							name = L["World PvP queues"],
							desc = L["Show information for World PvP queues."],
							width = 'full',
						},
					},
				},
			},
		},
		Tooltip = {
			type = 'group',
			order = 2,
			name = L["Customizable tooltip options"],
			childGroups = 'tab',
			get = function(info)
				return db.Frame[ info[#info] ];
			end,
			set = function(info, value)
				db.Frame[ info[#info] ] = value;
				addon:UpdateFrameArt();
			end,
			disabled = function()
				return db.FrameType ~= 'custom';
			end,
			args = {
				__desc = {
					type = 'description',
					order = 0,
					name = L["These options are only available when using the Customizable tooltip frame."],
					hidden = function()
						return db.ShowFrame and db.FrameType == 'custom';
					end,
					disabled = false,
				},
				Data = {
					type = 'group',
					order = 1,
					name = L["Queue data"],
					desc = L["Tooltip information options"],
					get = function(info)
						return db.Frame.Data[ info[#info] ];
					end,
					set = function(info, value)
						db.Frame.Data[ info[#info] ] = value;
					end,
					args = {
						Type = {
							type = 'toggle',
							order = 1,
							name = L["Dungeon queue type"],
							desc = L["Show the type of dungeon queue you are waiting in."],
							width = 'double',
						},
						Tank = {
							type = 'toggle',
							order = 2,
							name = L["Tank queue times"],
							desc = L["Show the estimated queue times for Tanks."],
							width = 'double',
						},
						Healer = {
							type = 'toggle',
							order = 3,
							name = L["Healer queue times"],
							desc = L["Show the estimated queue times for Healers."],
							width = 'double',
						},
						DPS = {
							type = 'toggle',
							order = 4,
							name = L["DPS queue times"],
							desc = L["Show the estimated queue times for Damage dealers."],
							width = 'double',
						},
						Self = {
							type = 'toggle',
							order = 5,
							name = L["Personal queue time"],
							desc = L["Show the estimated queue time for your current group."],
							width = 'double',
						},
						Party = {
							type = 'toggle',
							order = 6,
							name = L["Number of party members found"],
							desc = L["Show information about the players and roles found for the current group."],
							width = 'double',
						},
						Found = {
							type = 'multiselect',
							order = 7,
							name = L["Party members found information"],
							desc = L["Toggle display of total number of players, tanks, healers and damagers found."],
							width = 'double',
							disabled = function()
								return not db.Frame.Data.Party;
							end,
							get = function(info, key)
								return db.Frame.Data.Found[key];
							end,
							set = function(info, key, value)
								db.Frame.Data.Found[key] = value;
							end,
							values = {
								Total = L["Total number of players"],
								Tank = L["Tank"],
								Healer = L["Healer"],
								DPS = L["DPS"],
							},
						},
					},
				},
				Backdrop = {
					type = 'group',
					order = 2,
					name = L["Backdrop"],
					desc = L["Tooltip background and border options"],
					get = function(info)
						if info.type == 'color' then
							local t = db.Frame.Backdrop[ info[#info] ];
							return t.r, t.g, t.b, t.a;
						else
							return db.Frame.Backdrop[ info[#info] ];
						end
					end,
					set = function(info, ...)
						if info.type == 'color' then
							local t = db.Frame.Backdrop[ info[#info] ];
							t.r, t.g, t.b, t.a = ...;
						else
							db.Frame.Backdrop[ info[#info] ] = ...;
						end
						addon:UpdateFrameArt();
					end,
					args = {
						Background = {
							type = 'select',
							order = 1,
							name = L["Background texture"],
							desc = L["Texture used as the tooltip's background."],
							dialogControl = 'LSM30_Background',
							values = AceGUIWidgetLSMlists.background,
							width = 'full',
						},
						BackgroundColor = {
							type = 'color',
							order = 2,
							name = L["Background texture color"],
							desc = L["Color used to tint the tooltip's background texture.\n|cffffd200Note|r: Darker textures are less effected by this option."],
							width = 'full',
						},
						Tile = {
							type = 'toggle',
							order = 3,
							name = L["Tile the background texture"],
							desc = L["Repeat the background texture horizontally and vertically."],
							width = 'full',
						},
						TileSize = {
							type = 'range',
							order = 4,
							name = L["Background tile size"],
							desc = L["Size of the blocks used when tiling the background texture."],
							width = 'full',
							min = 2,
							max = 64,
							step = 1,
							bigStep = 2,
							disabled = function(info)
								return not db.Frame.Backdrop.Tile;
							end,
						},
						Inset = {
							type = 'range',
							order = 5,
							name = L["Background inset"],
							desc = L["Distance between the border and the background texture."],
							width = 'full',
							min = 0,
							max = 32,
							step = 1,
							bigStep = 2,
						},
						Border = {
							type = 'select',
							order = 7,
							name = L["Border texture"],
							desc = L["Texture used as the tooltip's border."],
							dialogControl = 'LSM30_Border',
							values = AceGUIWidgetLSMlists.border,
							width = 'full',
						},
						BorderColor = {
							type = 'color',
							order = 8,
							name = L["Border texture color"],
							desc = L["Color used to tint the tooltip's border texture.\n|cffffd200Note|r: Darker textures are less effected by this option."],
							width = 'full',
						},
						EdgeSize = {
							type = 'range',
							order = 9,
							name = L["Border size"],
							desc = L["Thickness of the border texture."],
							width = 'full',
							min = 2,
							max = 32,
							step = 1,
							bigStep = 2,
						},
					},
				},
				Text = {
					type = 'group',
					order = 3,
					name = L["Text"],
					desc = L["Text appearance options"],
					get = function(info)
						if info.type == 'color' then
							local t = db.Frame.Text[ info[#info] ];
							return t.r, t.g, t.b, t.a;
						else
							return db.Frame.Text[ info[#info] ];
						end
					end,
					set = function(info, ...)
						if info.type == 'color' then
							local t = db.Frame.Text[ info[#info] ];
							t.r, t.g, t.b, t.a = ...;
						else
							db.Frame.Text[ info[#info] ] = ...;
						end
					end,
					args = {
						Font = {
							type = 'select',
							order = 1,
							name = L["Font"],
							desc = L["Font used for the tooltip text."],
							dialogControl = 'LSM30_Font',
							values = AceGUIWidgetLSMlists.font,
							width = 'full',
						},
						Size = {
							type = 'range',
							order = 2,
							name = L["Text size"],
							desc = L["Font size used for the tooltip text."],
							width = 'full',
							min = 4,
							max = 20,
							step = 1,
						},
						Outline = {
							type = 'select',
							order = 3,
							name = L["Text outline"],
							desc = L["Add an outline to the tooltip text."],
							width = 'full',
							values = {
								[" "] = L["No outline"],
								["OUTLINE"] = L["Thin outline"],
								["THICKOUTLINE"] = L["Thick outline"],
							},
						},
						Color = {
							type = 'color',
							order = 4,
							name = L["Text color"],
							desc = L["Color used for the tooltip text."],
							width = 'full',
						},
					},
				},
			},
		},
	--]===]
	},
};
